@@ -1,4 +1,3 @@
-# from canalyst_candas.candas import FormulaTree, FuncMusic, Model, ModelMap, ModelSet
 from canalyst_candas.candas import (
     FuncMusic,
     Model,
@@ -6,7 +5,8 @@ from canalyst_candas.candas import (
     ModelSet,
     Chart,
 )
-from canalyst_candas.utils import get_chart_brand_config, unstack_dataframe
+from canalyst_candas.utils import get_chart_brand_config
+from canalyst_candas.datafunctions import DataFunctions
 import canalyst_candas.version as version
 
 __version__ = version.__version__
