@@ -204,20 +204,8 @@ class FileProvider(ConfigProvider):
         - S3 access ID not provided
         - S3 secret key not provided
         """
-        config_file = Path(f"{settings.ROOT_DIR}/keys.json")
+        config_file = f"{Path.home()}/canalyst/keys.json"
         possible_configs: List[Path] = []
-        if not config_file.is_file():
-            home = Path.home()
-            possible_configs.extend(
-                _dir
-                for _dir in home.rglob("canalyst/keys.json")
-                if not re.search("Trash", str(_dir))
-            )
-
-            try:
-                config_file = possible_configs[0]
-            except IndexError:
-                raise ConfigException("Configuration file not found")
 
         if len(possible_configs) > 1:
             new_line_point = "\n - "
@@ -235,8 +223,8 @@ class FileProvider(ConfigProvider):
         try:
             with open(config_file) as _file:
                 config = json.load(_file)
-        except (json.JSONDecodeError, PermissionError):
-            raise ConfigException("Configuration file unreadable")
+        except (json.JSONDecodeError, PermissionError, FileNotFoundError):
+            raise ConfigException("Configuration file unreadable or unreachable")
 
         if not config.get("canalyst_api_key"):
             return None
