@@ -21,6 +21,7 @@ def create_config():
         if not Path(new_path).exists():
             Path(new_path).mkdir()
         config_file = new_path / "keys.json"
+
         config_file_json = {
             "canalyst_api_key": "",
             "s3_access_key_id": "",
@@ -31,8 +32,13 @@ def create_config():
             "wp_host": "",
             "verify_ssl": True,
         }
-        config_file.write_text(json.dumps(config_file_json, indent=2))
-        print("A configuration file has been created for you in \n" f"{config_file}.")
+        try:
+            config_file.write_text(json.dumps(config_file_json, indent=2))
+            print(
+                "A configuration file has been created for you in \n" f"{config_file}."
+            )
+        except:
+            print("Failed to create config file in \n" f"{config_file}.")
 
 
 CONFIG = create_config()
