@@ -9,7 +9,7 @@ from canalyst_candas.configuration.exceptions import ConfigException
 from python_graphql_client import GraphqlClient
 import numpy as np
 from urllib.parse import quote_plus
-from io import StringIO
+from io import BytesIO, StringIO
 from canalyst_candas import settings
 import re
 import boto3
@@ -44,8 +44,9 @@ SCENARIO_URL_FORECAST = (
     "api/equity-model-series/{csin}/equity-models/"
     "{version}/scenarios/{scenario_id}/forecast-periods/"
 )
+BULK_DATA_URL = "api/equity-model-series/{csin}/equity-models/{version}/bulk-data/{bulk_data_key}.{file_type}"
 
-HISTORICAL_PERIODS_TO_FETCH = 24
+HISTORICAL_PERIODS_TO_FETCH = 36
 
 BRAND_CONFIG_DEFAULTS = {
     "chart_plot_colors": [
@@ -74,13 +75,41 @@ BRAND_CONFIG_DEFAULTS = {
 }
 
 
-class CsvDataKeys(Enum):
+class BulkDataKeys(Enum):
     FORECAST_DATA = "forecast-data"
     HISTORICAL_DATA = "historical-data"
     NAME_INDEX = "name-index"
     MODEL_INFO = "model-info"
 
 
+class BulkDataFileType(Enum):
+    CSV = "csv"
+    PARQUET = "parquet"
+
+
+# Setting it up as a local dict instead of based on the /bulk-data endpoint results
+# to allow for faster generation (less queries to the  MDS),
+# at the cost of duplication across the MDS & Candas.
+BULK_DATA_KEY_FILE_TYPES = {
+    BulkDataKeys.FORECAST_DATA: [
+        BulkDataFileType.CSV.value,
+        BulkDataFileType.PARQUET.value,
+    ],
+    BulkDataKeys.HISTORICAL_DATA: [
+        BulkDataFileType.CSV.value,
+        BulkDataFileType.PARQUET.value,
+    ],
+    BulkDataKeys.NAME_INDEX: [
+        BulkDataFileType.CSV.value,
+        BulkDataFileType.PARQUET.value,
+    ],
+    BulkDataKeys.MODEL_INFO: [
+        # model info _only_ has CSV due to incompatibility with parquet
+        BulkDataFileType.CSV.value
+    ],
+}
+
+
 def set_api_key(key, key_file_path):
     """
     Loads API key from path
@@ -268,63 +297,73 @@ class Getter:
 
 
 def get_data_set_from_mds(
-    csv_data_key, csin, model_version, auth_headers, log, mds_host=settings.MDS_HOST
+    bulk_data_key: BulkDataKeys,
+    file_type: str,
+    csin: str,
+    model_version: str,
+    auth_headers: Dict[str, str],
+    log: LogFile,
+    mds_host: str = settings.MDS_HOST,
 ):
     """
-    Pulls a CSV file from the MDS at the equity-model endpoint and returns it in a dataframe.
+    Pulls a bulk data file from the MDS at the equity-model endpoint and returns it in a dataframe.
 
-    Different types of CSVs are available, listed in the CsvDataKeys enum.
+    Different types are available, listed in the BulkDataKeys enum. Different formats are also
+    available, listed in the BULK_DATA_KEY_FILE_TYPES based on the type.
     """
 
-    url_candidates = _get_data_set_urls_from_mds(
-        csin, model_version, auth_headers, log, mds_host
-    )
-    url = _get_data_set_csv_url(url_candidates, csv_data_key.value, log)
-
-    if url is None:
-        return
-
-    response = get_request(url, auth_headers, log)
-    csv_string = response.content.decode("utf-8")
-    df = pd.read_csv(StringIO(csv_string))
-    return df
-
-
-def _get_data_set_csv_url(
-    csv_url_candidates,
-    csv_data_type,
-    log,
-):
-    """
-    Gets the url that matches the given 'csv_data_type' from the list of 'csv_url_candidates'
-    """
-    csv_to_download = [
-        candidate for candidate in csv_url_candidates if csv_data_type in candidate
-    ]
-
-    if not csv_to_download or len(csv_to_download) != 1:
-        log.write(
-            f"Candas: Error with retrieving the '{csv_data_type}' URL from the list '{csv_url_candidates}'."
+    available_file_types = BULK_DATA_KEY_FILE_TYPES[bulk_data_key]
+    if file_type not in available_file_types:
+        print(
+            f"{bulk_data_key.value} is not available in the requested file type: {file_type}.",
+            f"It is available in the following type(s): {available_file_types}.",
         )
         return
 
-    return csv_to_download[0]
+    url = _get_mds_bulk_data_url(
+        bulk_data_key,
+        file_type,
+        csin,
+        model_version,
+        mds_host,
+    )
 
+    response = get_request(url, auth_headers, log)
 
-def _get_data_set_urls_from_mds(
-    csin, model_version, auth_headers, log, mds_host=settings.MDS_HOST
-):
-    """
-    Get's the candascsvdata_set list from the equity model instance endpoint.
-    """
-    url = f"{mds_host}/{EQUITY_MODEL_URL.format(csin=csin, version=model_version)}"
+    if file_type == BulkDataFileType.CSV.value:
+        csv_string = response.content.decode("utf-8")
+        df = pd.read_csv(StringIO(csv_string))
+        return df
+    elif file_type == BulkDataFileType.PARQUET.value:
+        df = pd.read_parquet(BytesIO(response.content))
 
-    response_content = get_request_json_content(url, auth_headers, log)
+        if bulk_data_key in [BulkDataKeys.FORECAST_DATA, BulkDataKeys.HISTORICAL_DATA]:
+            # parquet values are set as strings by default, manually set to floats/ints
+            df["value"] = pd.to_numeric(df["value"])
+            # parquet dates are set as datetime.date objects by default, set to strings
+            df["period_end_date"] = df["period_end_date"].astype(str)
+            df["period_start_date"] = df["period_start_date"].astype(str)
 
-    if not response_content:
-        return []
+        return df
     else:
-        return response_content.get("candascsvdata_set")
+        print(
+            f"Unable to retrieve {bulk_data_key} with file type {file_type} from"
+            f"the following URL: {url}."
+        )
+        return
+
+
+def _get_mds_bulk_data_url(
+    bulk_data_key: BulkDataKeys,
+    file_type,
+    csin,
+    model_version,
+    mds_host: str = settings.MDS_HOST,
+):
+    return (
+        f"{mds_host}/"
+        f"{BULK_DATA_URL.format(csin=csin, version=model_version, bulk_data_key=bulk_data_key.value, file_type=file_type)}"
+    )
 
 
 def save_guidance_csv(df, ticker, filename):
@@ -519,6 +558,10 @@ def map_scenario_urls(json):
     return scenario_map
 
 
+def print_data_dir(config):
+    print(f"The data is downloaded in {config.default_dir}")
+
+
 def get_name_index_from_csv(ticker, config):
     default_dir = config.default_dir
 
@@ -993,6 +1036,7 @@ def get_model_info(ticker, auth_headers, log: LogFile, mds_host=settings.MDS_HOS
     earnings_update_type = json.get("latest_equity_model", {}).get(
         "earnings_update_type"
     )
+    publish_date = json.get("latest_equity_model", {}).get("published_at")
 
     periods = get_historical_periods(
         csin,
@@ -1003,7 +1047,14 @@ def get_model_info(ticker, auth_headers, log: LogFile, mds_host=settings.MDS_HOS
         HISTORICAL_PERIODS_TO_FETCH,
     )
 
-    model_info[ticker] = (csin, company, latest_version, periods, earnings_update_type)
+    model_info[ticker] = (
+        csin,
+        company,
+        latest_version,
+        periods,
+        earnings_update_type,
+        publish_date,
+    )
 
     return_string = (
         f"{mds_host}/api/equity-model-series/{csin}/equity-models/"
@@ -1548,38 +1599,3 @@ def _validate_colors(
         and match_ax_spine_color
         and match_chart_bg_color
     )
-
-
-def unstack_dataframe(df, ticker="", time_series_name=[], period_type="period_name"):
-    """
-    A function to unstack a dataframe with period_name as index and either all or specific time series names as column headers.
-
-    Parameters
-    ----------
-    ticker: str
-    time_series_name: list
-    period_type: string
-
-    Returns
-    ----------
-    Pandas DataFrame
-    """
-
-    if ticker != "":
-        df = df.loc[df["ticker"] == ticker]
-
-    if type(time_series_name) is list and len(time_series_name):
-        df = df.loc[df["time_series_name"].isin(time_series_name)]
-
-    elif type(time_series_name) is str:
-        df = df.loc[df["time_series_name"] == time_series_name]
-
-    dx = (
-        df[["ticker", "value", "time_series_name", period_type]]
-        .set_index(["ticker", period_type, "time_series_name"])
-        .unstack()
-    )
-    dx.columns = ["_".join(column) for column in dx.columns.to_flat_index()]
-    dx = dx.reset_index()
-    dx.columns = [c.replace("value_", "") for c in list(dx.columns)]
-    return dx
